@@ -43,9 +43,9 @@ public:
         DescriptionRole = Qt::UserRole + 1,
         PluginNameRole,
         ScreenhotRole,
-        UninstallableRole
+        UninstallableRole,
     };
-    explicit KCMPlymouth(QObject* parent, const QVariantList& args);
+    explicit KCMPlymouth(QObject *parent, const QVariantList &args);
     ~KCMPlymouth() Q_DECL_OVERRIDE;
 
     QStandardItemModel *themesModel();
